# morning-assistant
Have a virtual assistant deliver you local weather and world news on demand!

### Setup
Install the CLI:

    pip3 install morning-assistant

Setup your preferences:

    export NAME='{your name}'
    export CITY='{your city}'

### Usage
Run `assistant`. On run, you'll get weather in your city and news spoken to you!

**Note**: Macs only.